<img
  src="https://res.cloudinary.com/canonical/image/fetch/{{ std_def_cloudinary_options }}/{{ url }}"
  {%- if hi_def %}
  srcset="https://res.cloudinary.com/canonical/image/fetch/c_limit,{{ hi_def_cloudinary_options }}/{{ url }} 2x"
  {%- endif %}
  alt="{{ alt }}"
  width="{{ width }}"
  {%- if height %}
  height="{{ height }}"
  {%- endif %}
  loading="{{ loading }}"
  {%- for attr_name, attr_value in attrs.items() %}
  {{ attr_name }}="{{ attr_value }}"
  {%- endfor %}
/>
